==> 1.0.0.tar.gz: lib/src/eventPost/controller/eventController.dart <==
import 'dart:convert';

import 'package:event_analysis_library/event_analysis_library.dart';
import 'package:event_analysis_library/src/eventPost/request/initial_log_repository.dart';
import 'package:event_analysis_library/src/eventPost/request/post_event_repository.dart';
import 'package:event_analysis_library/src/eventPost/request/sdkInitializationRepository.dart';
import 'package:event_analysis_library/src/eventPost/request/user_identity_repository.dart';
import 'package:event_analysis_library/src/shared/model/sdk_initialization/sdk_initialization.dart';

class EventController{
  final CreateEvent createEvent;

  EventController(this.createEvent);

  //repository
  final _sdkInitializationRepo = SdkInitializationRepository();
  final _initialLogRepo = InitialLogRepository();
  final _postEventRepo = PostEventRepository();
  final _userIdentityRepo = UserIdentityRepository();

  initializeSdk(String productKey, String initialLog) async {
    await _sdkInitializationRepo.initializeSdk(productKey).then((value) async {
      if(value.hasError){
        print(value.errorMessage);
      }else{
        print("POST INITIAL");
        await _initialLogRepo.postInitialLog(value.response!.result.token, value.response!.result.project_id, initialLog).then((val) {
          print(val.hasError);
          if(value.hasError){
            print(value.errorMessage);
          }else{
            print("POST INITIAL SUCCESSFUL");
            createEvent.initializationSdk(value.response!);
          }
        });
      }
    });
  }

  eventPost(String token, String productKey, String eventLog) async {
    await _postEventRepo.postEvent(token, productKey, eventLog).then((value) {
      if(value.hasError){
        print(value.errorMessage);
      }else{
        print('Log Posted');
      }
    });
  }

  userIdentity(String token, String productKey, String eventLog) async {
    await _userIdentityRepo.userIdentity(token, productKey, eventLog).then((value) {
      if(value.hasError){
        print(value.errorMessage);
      }else{
        print('User Identified');
      }
    });
  }
}

==> 1.0.2.tar.gz: lib/src/eventPost/controller/eventController.dart <==
import 'dart:convert';

import 'package:event_analysis_library/event_analysis_library.dart';
import 'package:event_analysis_library/src/eventPost/request/initial_log_repository.dart';
import 'package:event_analysis_library/src/eventPost/request/post_event_repository.dart';
import 'package:event_analysis_library/src/eventPost/request/sdkInitializationRepository.dart';
import 'package:event_analysis_library/src/eventPost/request/user_identity_repository.dart';

class EventController {
  final CreateEvent createEvent;

  EventController(this.createEvent);

  //repository
  final _sdkInitializationRepo = SdkInitializationRepository();
  final _initialLogRepo = InitialLogRepository();
  final _postEventRepo = PostEventRepository();
  final _userIdentityRepo = UserIdentityRepository();

  Future<bool> initializeSdk(String productKey, String initialLog) async {
    bool result = false;
    await _sdkInitializationRepo.initializeSdk(productKey).then((value) async {
      if (value.hasError) {
        print(value.errorMessage);
        result = false;
      } else {
        print("POST INITIAL");
        await _initialLogRepo
            .postInitialLog(value.response!.result.token,
                value.response!.result.project_id, initialLog)
            .then((val) {
          print(val.hasError);
          if (value.hasError) {
            print(value.errorMessage);
            result = false;
          } else {
            print("POST INITIAL SUCCESSFUL");
            createEvent.initializationSdk(value.response!);
            result = true;
          }
        });
      }
    });
    return result;
  }

  eventPost(String token, String productKey, String eventLog) async {
    await _postEventRepo.postEvent(token, productKey, eventLog).then((value) {
      if (value.hasError) {
        print(value.errorMessage);
      } else {
        print('Log Posted');
      }
    });
  }

  userIdentity(String token, String productKey, String eventLog) async {
    await _userIdentityRepo
        .userIdentity(token, productKey, eventLog)
        .then((value) {
      if (value.hasError) {
        print(value.errorMessage);
      } else {
        print('User Identified');
      }
    });
  }
}
